summaryrefslogtreecommitdiffstats
path: root/kbugbuster/backend/bugserver.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
commit4ae0c208b66e0f7954e194384464fe2d0a2c56dd (patch)
treeb0a7cd1c184f0003c0292eb416ed27f674f9cc43 /kbugbuster/backend/bugserver.cpp
parent1964ea0fb4ab57493ca2ebb709c8d3b5395fd653 (diff)
downloadtdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.tar.gz
tdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1157652 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kbugbuster/backend/bugserver.cpp')
-rw-r--r--kbugbuster/backend/bugserver.cpp76
1 files changed, 38 insertions, 38 deletions
diff --git a/kbugbuster/backend/bugserver.cpp b/kbugbuster/backend/bugserver.cpp
index 0e6a70e6..768b76cd 100644
--- a/kbugbuster/backend/bugserver.cpp
+++ b/kbugbuster/backend/bugserver.cpp
@@ -49,10 +49,10 @@ void BugServer::init()
{
mCache = new BugCache( identifier() );
- QString commandsFile = locateLocal( "appdata", identifier() + "commands" );
+ TQString commandsFile = locateLocal( "appdata", identifier() + "commands" );
mCommandsFile = new KSimpleConfig( commandsFile );
- QString bugzilla = mServerConfig.bugzillaVersion();
+ TQString bugzilla = mServerConfig.bugzillaVersion();
if ( bugzilla == "KDE" ) mProcessor = new DomProcessor( this );
else if ( bugzilla == "2.10" ) mProcessor = new HtmlParser_2_10( this );
@@ -82,9 +82,9 @@ BugServerConfig &BugServer::serverConfig()
return mServerConfig;
}
-QString BugServer::identifier()
+TQString BugServer::identifier()
{
- QString id = mServerConfig.baseUrl().host();
+ TQString id = mServerConfig.baseUrl().host();
return id;
}
@@ -102,7 +102,7 @@ KURL BugServer::packageListUrl()
return url;
}
-KURL BugServer::bugListUrl( const Package &product, const QString &component )
+KURL BugServer::bugListUrl( const Package &product, const TQString &component )
{
KURL url = mServerConfig.baseUrl();
@@ -132,7 +132,7 @@ KURL BugServer::bugLink( const Bug &bug )
return url;
}
-KURL BugServer::attachmentViewLink( const QString &id )
+KURL BugServer::attachmentViewLink( const TQString &id )
{
KURL url = mServerConfig.baseUrl();
@@ -142,7 +142,7 @@ KURL BugServer::attachmentViewLink( const QString &id )
return url;
}
-KURL BugServer::attachmentEditLink( const QString &id )
+KURL BugServer::attachmentEditLink( const TQString &id )
{
KURL url = mServerConfig.baseUrl();
@@ -152,7 +152,7 @@ KURL BugServer::attachmentEditLink( const QString &id )
return url;
}
-Bug::Status BugServer::bugStatus( const QString &str )
+Bug::Status BugServer::bugStatus( const TQString &str )
{
if ( str == "UNCONFIRMED" ) {
return Bug::Unconfirmed;
@@ -173,7 +173,7 @@ Bug::Status BugServer::bugStatus( const QString &str )
}
}
-Bug::Severity BugServer::bugSeverity( const QString &str )
+Bug::Severity BugServer::bugSeverity( const TQString &str )
{
if ( str == "critical" ) {
return Bug::Critical;
@@ -204,9 +204,9 @@ void BugServer::writeConfig( KConfig * /*config*/ )
bool BugServer::queueCommand( BugCommand *cmd )
{
// mCommands[bug] is a QPtrList. Get or create, set to autodelete, then append command.
mCommands[cmd->bug().number()].setAutoDelete( true );
- QPtrListIterator<BugCommand> cmdIt( mCommands[cmd->bug().number()] );
+ TQPtrListIterator<BugCommand> cmdIt( mCommands[cmd->bug().number()] );
for ( ; cmdIt.current(); ++cmdIt )
if ( cmdIt.current()->type() == cmd->type() )
return false;
@@ -214,10 +214,10 @@ bool BugServer::queueCommand( BugCommand *cmd )
return true;
}
-QPtrList<BugCommand> BugServer::queryCommands( const Bug &bug ) const
+TQPtrList<BugCommand> BugServer::queryCommands( const Bug &bug ) const
{
CommandsMap::ConstIterator it = mCommands.find( bug.number() );
- if (it == mCommands.end()) return QPtrList<BugCommand>();
+ if (it == mCommands.end()) return TQPtrList<BugCommand>();
else return *it;
}
@@ -227,14 +227,14 @@ bool BugServer::hasCommandsFor( const Bug &bug ) const
return it != mCommands.end();
}
-void BugServer::sendCommands( MailSender *mailer, const QString &senderName,
- const QString &senderEmail, bool sendBCC,
- const QString &recipient )
+void BugServer::sendCommands( MailSender *mailer, const TQString &senderName,
+ const TQString &senderEmail, bool sendBCC,
+ const TQString &recipient )
{
// Disable mail commands for non-KDE servers
if ( mServerConfig.baseUrl() != KURL( "http://bugs.kde.org" ) ) return;
- QString controlText;
+ TQString controlText;
// For each bug that has commands.....
CommandsMap::ConstIterator it;
@@ -242,7 +242,7 @@ void BugServer::sendCommands( MailSender *mailer, const QString &senderName,
Bug bug;
Package pkg;
// And for each command....
- QPtrListIterator<BugCommand> cmdIt( *it );
+ TQPtrListIterator<BugCommand> cmdIt( *it );
for ( ; cmdIt.current() ; ++cmdIt ) {
BugCommand* cmd = cmdIt.current();
bug = cmd->bug();
@@ -257,8 +257,8 @@ void BugServer::sendCommands( MailSender *mailer, const QString &senderName,
// implement message queueing for smtp
MailSender *directMailer = mailer->clone();
#if 0
- connect( directMailer, SIGNAL( status( const QString & ) ),
- this, SIGNAL( infoMessage( const QString & ) ) );
+ connect( directMailer, TQT_SIGNAL( status( const TQString & ) ),
+ this, TQT_SIGNAL( infoMessage( const TQString & ) ) );
#endif
if (!directMailer->send( senderName, senderEmail, cmd->mailAddress(),
cmd->bug().title().prepend( "Re: " ),
@@ -272,9 +272,9 @@ void BugServer::sendCommands( MailSender *mailer, const QString &senderName,
mCommandsFile->deleteGroup( bug.number(), true ); // done, remove command
mCache->invalidateBugDetails( bug );
if ( !pkg.isNull() ) {
- mCache->invalidateBugList( pkg, QString::null ); // the status of the bug comes from the buglist...
+ mCache->invalidateBugList( pkg, TQString::null ); // the status of the bug comes from the buglist...
- QStringList::ConstIterator it2;
+ TQStringList::ConstIterator it2;
for (it2 = pkg.components().begin();it2 != pkg.components().end();++it2) {
mCache->invalidateBugList( pkg, (*it2) ); // the status of the bug comes from the buglist...
}
@@ -297,7 +297,7 @@ void BugServer::sendCommands( MailSender *mailer, const QString &senderName,
mCommands.clear();
}
-void BugServer::clearCommands( const QString &bug )
+void BugServer::clearCommands( const TQString &bug )
{
mCommands.remove( bug );
mCommandsFile->deleteGroup( bug, true );
@@ -309,12 +309,12 @@ bool BugServer::commandsPending() const
else return false;
}
-QStringList BugServer::listCommands() const
+TQStringList BugServer::listCommands() const
{
- QStringList result;
+ TQStringList result;
CommandsMap::ConstIterator it;
for(it = mCommands.begin(); it != mCommands.end(); ++it ) {
- QPtrListIterator<BugCommand> cmdIt( *it );
+ TQPtrListIterator<BugCommand> cmdIt( *it );
for ( ; cmdIt.current() ; ++cmdIt ) {
BugCommand* cmd = cmdIt.current();
if (!cmd->controlString().isNull())
@@ -326,9 +326,9 @@ QStringList BugServer::listCommands() const
return result;
}
-QStringList BugServer::bugsWithCommands() const
+TQStringList BugServer::bugsWithCommands() const
{
- QStringList bugs;
+ TQStringList bugs;
CommandsMap::ConstIterator it;
for(it = mCommands.begin(); it != mCommands.end(); ++it ) {
@@ -343,7 +343,7 @@ void BugServer::saveCommands() const
CommandsMap::ConstIterator it;
for(it = mCommands.begin(); it != mCommands.end(); ++it ) {
mCommandsFile->setGroup( it.key() );
- QPtrListIterator<BugCommand> cmdIt( *it );
+ TQPtrListIterator<BugCommand> cmdIt( *it );
for ( ; cmdIt.current() ; ++cmdIt ) {
BugCommand* cmd = cmdIt.current();
cmd->save( mCommandsFile );
@@ -357,14 +357,14 @@ void BugServer::loadCommands()
{
mCommands.clear();
- QStringList bugs = mCommandsFile->groupList();
- QStringList::ConstIterator it;
+ TQStringList bugs = mCommandsFile->groupList();
+ TQStringList::ConstIterator it;
for( it = bugs.begin(); it != bugs.end(); ++it ) {
mCommandsFile->setGroup( *it );
- QMap<QString, QString> entries = mCommandsFile->entryMap ( *it );
- QMap<QString, QString>::ConstIterator it;
+ TQMap<TQString, TQString> entries = mCommandsFile->entryMap ( *it );
+ TQMap<TQString, TQString>::ConstIterator it;
for( it = entries.begin(); it != entries.end(); ++it ) {
- QString type = it.key();
+ TQString type = it.key();
BugCommand *cmd = BugCommand::load( mCommandsFile, type );
if ( cmd ) {
mCommands[cmd->bug().number()].setAutoDelete(true);
@@ -384,16 +384,16 @@ const Package::List &BugServer::packages() const
return mPackages;
}
-void BugServer::setBugs( const Package &pkg, const QString &component,
+void BugServer::setBugs( const Package &pkg, const TQString &component,
const Bug::List &bugs )
{
- QPair<Package, QString> pkg_key = QPair<Package, QString>(pkg, component);
+ QPair<Package, TQString> pkg_key = QPair<Package, TQString>(pkg, component);
mBugs[ pkg_key ] = bugs;
}
-const Bug::List &BugServer::bugs( const Package &pkg, const QString &component )
+const Bug::List &BugServer::bugs( const Package &pkg, const TQString &component )
{
- QPair<Package, QString> pkg_key = QPair<Package, QString>(pkg, component);
+ QPair<Package, TQString> pkg_key = QPair<Package, TQString>(pkg, component);
return mBugs[ pkg_key ];
}
@@ -204,9 +204,9 @@ void BugServer::writeConfig( KConfig * /*config*/ )
bool BugServer::queueCommand( BugCommand *cmd )
{
- // mCommands[bug] is a QPtrList. Get or create, set to autodelete, then append command.
+ // mCommands[bug] is a TQPtrList. Get or create, set to autodelete, then append command.
mCommands[cmd->bug().number()].setAutoDelete( true );